@@ -1,4 +1,6 @@
 pub mod config_watcher;
+pub mod daemon;
 pub mod debt_reporter;
+pub mod milestone;
 pub mod tcp_relay_listener;
 pub mod unix_relay_listener;
